@@ -41,6 +41,7 @@ class MeasurementTree:
         self.dataset = None
         self.metadata = {}
         self.attrs = None
+        self.eLab_meta = None
 
         if not override:
             try:
@@ -140,6 +141,7 @@ class MeasurementTree:
         self.devices = {i: self.convert_to_dict(k, truncate=True) for (i, k) in self.f['devices'].items()}
         self.labbook = {i: self.convert_to_dict(k) for (i, k) in self.f['labbook'].items()}
         self.logs = self.convert_to_dict(self.f['measurement/log'])
+        self.eLab_meta = self.get_elab_attrs()
         """
         ////////////////////////////////////////////////////////
         This reconstructs the multidimensional measurement tree.
@@ -236,7 +238,7 @@ class MeasurementTree:
                     pass
                 line = textwrap.indent(printout, ' '*2*int(j.tree_indent))
                 print_tree_list.append(line)
-                print(line)
+                # print(line)
         self.tree_string = '\n'.join(print_tree_list)
 
 
@@ -353,6 +355,7 @@ class MeasurementTree:
             coords = {}
             shape = []
             units = []
+            segments = []
 
             while parent is not None:
                 try:
@@ -387,7 +390,7 @@ class MeasurementTree:
                         if isinstance(self.definition[parent_row]['start'], list):
                             part = []
                             roi = []
-                            # TODO: Find a way to save this information for later use. Save list of steps in array.
+                            # TODO: Find a way to save ste for later use. Save list of steps in array.
                             for sta, sto, ste, eq in zip(self.definition[parent_row]['start'],
                                                          self.definition[parent_row]['stop'],
                                                          self.definition[parent_row]['steps'],
@@ -407,12 +410,14 @@ class MeasurementTree:
                 if row_data is not None:
                     coords[control_name] = row_data
                     units.append(unit)
+                    segments.append(roi)
                 parent_row = parent.parent_row
                 parent = parent.parent_group
 
             dims = list(coords.keys())
             units.reverse()
             dims.reverse()
+            segments.reverse()
 
             self.indicator_name, indicator_unit = self.get_units(self.indicator_name)
 
@@ -426,6 +431,7 @@ class MeasurementTree:
                     scales = self.get_scales(self.target[row][0], i)
                     coords[coord_name] = scales
                     dims.append(coord_name)
+                    segments.append(None)
                     unit = metadata['unit'][i]
                     units.append(unit)
             else:
@@ -434,6 +440,7 @@ class MeasurementTree:
                 for i, dat_shape in enumerate(data_shape):
                     coord_name = self.avoid_duplicate(coord_name, coords.keys())
                     coords[coord_name] = np.arange(dat_shape)
+                    segments.append(None)
                     dims.append(coord_name)
                     units.append('')
 
@@ -465,8 +472,9 @@ class MeasurementTree:
             print()
             self.array = xr.DataArray(self.data, dims=dims, coords=coords, name=self.indicator_name)
             # Add units to Attributes
-            for x, y in zip(dims, units):
+            for x, y, z in zip(dims, units, segments):
                 self.array[x].attrs['units'] = y
+                self.array[x].attrs['segments'] = z
             self.array.attrs['units'] = indicator_unit
             all_indicators.append(self.array)
 
@@ -563,6 +571,19 @@ class MeasurementTree:
         except KeyError:
             return None
 
+    def get_elab_attrs(self, group: str = 'eLab') -> dict:
+        try:
+            group_dict = {key: value for key, value in self.f[group].attrs.items()}
+            for key, value in group_dict.items():
+                try:
+                    group_dict[key] = value.decode('UTF-8')
+                except AttributeError:
+                    pass
+        except AttributeError:
+            raise Warning('The eLab Group could not be found in the hdf5 file.')
+        return group_dict
+
+
     @staticmethod
     def check_for_sp_char(text):
         import re
